summaryrefslogtreecommitdiff
path: root/gdk/gdkdevice.h
diff options
context:
space:
mode:
authorAlexander Larsson <alexl@redhat.com>2018-03-20 12:05:26 +0100
committerAlexander Larsson <alexl@redhat.com>2018-03-20 12:05:26 +0100
commit9a7e721181ce714ab248429dc1258984b9e10748 (patch)
tree73d69b5c298d61cc9c045bed3bc7e54dde4aa15c /gdk/gdkdevice.h
parent890080ebf7a12199d5500fbbf6a0daf06cc2d35f (diff)
downloadgtk+-9a7e721181ce714ab248429dc1258984b9e10748.tar.gz
GdkSurface: Rename various functions and variables
This is an automatic rename of various things related to the window->surface rename. Public symbols changed by this is: GDK_MODE_WINDOW gdk_device_get_window_at_position gdk_device_get_window_at_position_double gdk_device_get_last_event_window gdk_display_get_monitor_at_window gdk_drag_context_get_source_window gdk_drag_context_get_dest_window gdk_drag_context_get_drag_window gdk_draw_context_get_window gdk_drawing_context_get_window gdk_gl_context_get_window gdk_synthesize_window_state gdk_surface_get_window_type gdk_x11_display_set_window_scale gsk_renderer_new_for_window gsk_renderer_get_window gtk_text_view_buffer_to_window_coords gtk_tree_view_convert_widget_to_bin_window_coords gtk_tree_view_convert_tree_to_bin_window_coords The commands that generated this are: git sed -f g "GDK window" "GDK surface" git sed -f g window_impl surface_impl (cd gdk; git sed -f g impl_window impl_surface) git sed -f g WINDOW_IMPL SURFACE_IMPL git sed -f g GDK_MODE_WINDOW GDK_MODE_SURFACE git sed -f g gdk_draw_context_get_window gdk_draw_context_get_surface git sed -f g gdk_drawing_context_get_window gdk_drawing_context_get_surface git sed -f g gdk_gl_context_get_window gdk_gl_context_get_surface git sed -f g gsk_renderer_get_window gsk_renderer_get_surface git sed -f g gsk_renderer_new_for_window gsk_renderer_new_for_surface (cd gdk; git sed -f g window_type surface_type) git sed -f g gdk_surface_get_window_type gdk_surface_get_surface_type git sed -f g window_at_position surface_at_position git sed -f g event_window event_surface git sed -f g window_coord surface_coord git sed -f g window_state surface_state git sed -f g window_cursor surface_cursor git sed -f g window_scale surface_scale git sed -f g window_events surface_events git sed -f g monitor_at_window monitor_at_surface git sed -f g window_under_pointer surface_under_pointer (cd gdk; git sed -f g for_window for_surface) git sed -f g window_anchor surface_anchor git sed -f g WINDOW_IS_TOPLEVEL SURFACE_IS_TOPLEVEL git sed -f g native_window native_surface git sed -f g source_window source_surface git sed -f g dest_window dest_surface git sed -f g drag_window drag_surface git sed -f g input_window input_surface git checkout NEWS* po-properties po docs/reference/gtk/migrating-3to4.xml
Diffstat (limited to 'gdk/gdkdevice.h')
-rw-r--r--gdk/gdkdevice.h10
1 files changed, 5 insertions, 5 deletions
diff --git a/gdk/gdkdevice.h b/gdk/gdkdevice.h
index 67f7de0712..044b790448 100644
--- a/gdk/gdkdevice.h
+++ b/gdk/gdkdevice.h
@@ -73,7 +73,7 @@ typedef enum
* @GDK_MODE_DISABLED: the device is disabled and will not report any events.
* @GDK_MODE_SCREEN: the device is enabled. The device’s coordinate space
* maps to the entire screen.
* @GDK_MODE_WINDOW: the device is enabled. The device’s coordinate space
* is mapped to a single window. The manner in which this window
* is chosen is undefined, but it will typically be the same
* way in which the focus window for key events is determined.
@@ -84,7 +84,7 @@ typedef enum
{
GDK_MODE_DISABLED,
GDK_MODE_SCREEN,
- GDK_MODE_WINDOW
+ GDK_MODE_SURFACE
} GdkInputMode;
/**
@@ -172,7 +172,7 @@ void gdk_device_get_position (GdkDevice *device,
gint *y);
GDK_AVAILABLE_IN_ALL
GdkSurface *
- gdk_device_get_window_at_position
+ gdk_device_get_surface_at_position
(GdkDevice *device,
gint *win_x,
gint *win_y);
@@ -182,7 +182,7 @@ void gdk_device_get_position_double (GdkDevice *device,
gdouble *y);
GDK_AVAILABLE_IN_ALL
GdkSurface *
- gdk_device_get_window_at_position_double
+ gdk_device_get_surface_at_position_double
(GdkDevice *device,
gdouble *win_x,
gdouble *win_y);
@@ -242,7 +242,7 @@ void gdk_device_warp (GdkDevice *device,
gint y);
GDK_AVAILABLE_IN_ALL
-GdkSurface *gdk_device_get_last_event_window (GdkDevice *device);
+GdkSurface *gdk_device_get_last_event_surface (GdkDevice *device);
GDK_AVAILABLE_IN_ALL
const gchar *gdk_device_get_vendor_id (GdkDevice *device);
@@ -73,7 +73,7 @@ typedef enum
* @GDK_MODE_SCREEN: the device is enabled. The device’s coordinate space
* maps to the entire screen.
- * @GDK_MODE_WINDOW: the device is enabled. The device’s coordinate space
+ * @GDK_MODE_SURFACE: the device is enabled. The device’s coordinate space
* is mapped to a single window. The manner in which this window
* is chosen is undefined, but it will typically be the same